@@ -22,3 +22,7 @@ class FastTaskArguments:
     batch_size_per_gpu: int = field(16, '')
     learning_rate: float = field(5e-5, "The initial learning rate for Adam.")
     num_train_epochs: int = field(3, "Total number of training epochs to perform.")
+    max_seq_length: int = field(512, '')
+    multi_label: bool = field(False, '')
+    model_type: str = field('bert', '')
+    fp16: bool = field(False, '')
