@@ -1,4 +1,5 @@
-from ai_harness.configuration import Arguments, configclass, field, ComplexArguments, export, merge_fields
+from ai_harness.configuration import Arguments, configclass, field, ComplexArguments, export, merge_fields, \
+    to_json_string
 from ai_harness import configclasses
 from ai_harness import harnessutils as aiutils
 from ai_harness.fileutils import join_path, FileLineReader
